@@ -434,188 +434,6 @@ void hcid_dbus_simple_pairing_complete(bdaddr_t *local, bdaddr_t *peer,
 	device_simple_pairing_complete(device, status);
 }
 
-void hcid_dbus_inquiry_start(bdaddr_t *local)
-{
-	struct btd_adapter *adapter;
-	int state;
-
-	adapter = manager_find_adapter(local);
-	if (!adapter) {
-		error("Unable to find matching adapter");
-		return;
-	}
-
-	state = adapter_get_state(adapter);
-	state |= STD_INQUIRY;
-	adapter_set_state(adapter, state);
-	/*
-	 * Cancel pending remote name request and clean the device list
-	 * when inquiry is supported in periodic inquiry idle state.
-	 */
-	if (adapter_get_state(adapter) & PERIODIC_INQUIRY)
-		pending_remote_name_cancel(adapter);
-
-	/* Disable name resolution for non D-Bus clients */
-	if (!adapter_has_discov_sessions(adapter)) {
-		state = adapter_get_state(adapter);
-		state &= ~RESOLVE_NAME;
-		adapter_set_state(adapter, state);
-	}
-}
-
-static int found_device_req_name(struct btd_adapter *adapter)
-{
-	struct hci_request rq;
-	evt_cmd_status rp;
-	remote_name_req_cp cp;
-	struct remote_dev_info *dev, match;
-	int dd, req_sent = 0;
-	uint16_t dev_id = adapter_get_dev_id(adapter);
-
-	memset(&match, 0, sizeof(struct remote_dev_info));
-	bacpy(&match.bdaddr, BDADDR_ANY);
-	match.name_status = NAME_REQUIRED;
-
-	dev = adapter_search_found_devices(adapter, &match);
-	if (!dev)
-		return -ENODATA;
-
-	dd = hci_open_dev(dev_id);
-	if (dd < 0)
-		return -errno;
-
-	memset(&rq, 0, sizeof(rq));
-	rq.ogf    = OGF_LINK_CTL;
-	rq.ocf    = OCF_REMOTE_NAME_REQ;
-	rq.cparam = &cp;
-	rq.clen   = REMOTE_NAME_REQ_CP_SIZE;
-	rq.rparam = &rp;
-	rq.rlen   = EVT_CMD_STATUS_SIZE;
-	rq.event  = EVT_CMD_STATUS;
-
-	/* send at least one request or return failed if the list is empty */
-	do {
-		/* flag to indicate the current remote name requested */
-		dev->name_status = NAME_REQUESTED;
-
-		memset(&rp, 0, sizeof(rp));
-		memset(&cp, 0, sizeof(cp));
-		bacpy(&cp.bdaddr, &dev->bdaddr);
-		cp.pscan_rep_mode = 0x02;
-
-		if (hci_send_req(dd, &rq, HCI_REQ_TIMEOUT) < 0)
-			error("Unable to send HCI remote name req: %s (%d)",
-						strerror(errno), errno);
-
-		if (!rp.status) {
-			req_sent = 1;
-			break;
-		}
-
-		error("Remote name request failed with status 0x%02x",
-								rp.status);
-
-		/* if failed, request the next element */
-		/* remove the element from the list */
-		adapter_remove_found_device(adapter, &dev->bdaddr);
-
-		/* get the next element */
-		dev = adapter_search_found_devices(adapter, &match);
-	} while (dev);
-
-	hci_close_dev(dd);
-
-	if (!req_sent)
-		return -ENODATA;
-
-	return 0;
-}
-
-void hcid_dbus_inquiry_complete(bdaddr_t *local)
-{
-	struct btd_adapter *adapter;
-	int state;
-
-	adapter = manager_find_adapter(local);
-	if (!adapter) {
-		error("Unable to find matching adapter");
-		return;
-	}
-
-	/*
-	 * The following scenarios can happen:
-	 * 1. standard inquiry: always send discovery completed signal
-	 * 2. standard inquiry + name resolving: send discovery completed
-	 *    after name resolving
-	 * 3. periodic inquiry: skip discovery completed signal
-	 * 4. periodic inquiry + standard inquiry: always send discovery
-	 *    completed signal
-	 *
-	 * Keep in mind that non D-Bus requests can arrive.
-	 */
-	if (found_device_req_name(adapter) == 0)
-		return;
-
-	state = adapter_get_state(adapter);
-
-	/*
-	 * workaround to identify situation when there is no devices around
-	 * but periodic inquiry is active.
-	 */
-	if (!(state & STD_INQUIRY) && !(state & PERIODIC_INQUIRY)) {
-		state |= PERIODIC_INQUIRY;
-		adapter_set_state(adapter, state);
-	}
-
-	/* reset the discover type to be able to handle D-Bus and non D-Bus
-	 * requests */
-	state &= ~STD_INQUIRY;
-	state &= ~PERIODIC_INQUIRY;
-	adapter_set_state(adapter, state);
-}
-
-void hcid_dbus_periodic_inquiry_start(bdaddr_t *local, uint8_t status)
-{
-	struct btd_adapter *adapter;
-	int state;
-
-	/* Don't send the signal if the cmd failed */
-	if (status)
-		return;
-
-	adapter = manager_find_adapter(local);
-	if (!adapter) {
-		error("No matching adapter found");
-		return;
-	}
-
-	state = adapter_get_state(adapter);
-	state |= PERIODIC_INQUIRY;
-	adapter_set_state(adapter, state);
-}
-
-void hcid_dbus_periodic_inquiry_exit(bdaddr_t *local, uint8_t status)
-{
-	struct btd_adapter *adapter;
-	int state;
-
-	/* Don't send the signal if the cmd failed */
-	if (status)
-		return;
-
-	adapter = manager_find_adapter(local);
-	if (!adapter) {
-		error("No matching adapter found");
-		return;
-	}
-
-	/* reset the discover type to be able to handle D-Bus and non D-Bus
-	 * requests */
-	state = adapter_get_state(adapter);
-	state &= ~PERIODIC_INQUIRY;
-	adapter_set_state(adapter, state);
-}
-
 static char *extract_eir_name(uint8_t *data, uint8_t *type)
 {
 	if (!data || !type)
@@ -788,7 +606,7 @@ proceed:
 	adapter_remove_found_device(adapter, peer);
 
 	/* check if there is more devices to request names */
-	if (found_device_req_name(adapter) == 0)
+	if (adapter_resolve_names(adapter) == 0)
 		return;
 
 	state = adapter_get_state(adapter);
@@ -907,96 +725,8 @@ void hcid_dbus_disconn_complete(bdaddr_t *local, uint8_t status,
 	adapter_remove_connection(adapter, device, handle);
 }
 
-int set_service_classes(int dd, const uint8_t *cls, uint8_t value)
-{
-	uint32_t dev_class;
-
-	if (cls[2] == value)
-		return 0; /* Already set */
-
-	dev_class = (value << 16) | (cls[1] << 8) | cls[0];
-
-	debug("Changing service classes to 0x%06x", dev_class);
-
-	if (hci_write_class_of_dev(dd, dev_class, HCI_REQ_TIMEOUT) < 0) {
-		int err = -errno;
-		error("Can't write class of device: %s (%d)",
-						strerror(errno), errno);
-		return err;
-	}
-
-	return 0;
-}
-
-int set_major_and_minor_class(int dd, const uint8_t *cls,
-						uint8_t major, uint8_t minor)
-{
-	uint32_t dev_class;
-
-	dev_class = (cls[2] << 16) | ((cls[1] & 0x20) << 8) |
-						((major & 0xdf) << 8) | minor;
-
-	debug("Changing major/minor class to 0x%06x", dev_class);
-
-	if (hci_write_class_of_dev(dd, dev_class, HCI_REQ_TIMEOUT) < 0) {
-		int err = -errno;
-		error("Can't write class of device: %s (%d)",
-						strerror(errno), errno);
-		return err;
-	}
-
-	return 0;
-}
-
 /* Section reserved to device HCI callbacks */
 
-void hcid_dbus_setname_complete(bdaddr_t *local)
-{
-	struct btd_adapter *adapter;
-	int id, dd = -1;
-	read_local_name_rp rp;
-	struct hci_request rq;
-	const char *pname = (char *) rp.name;
-	char name[249];
-
-	adapter = manager_find_adapter(local);
-	if (!adapter) {
-		error("No matching adapter found");
-		return;
-	}
-
-	id = adapter_get_dev_id(adapter);
-	dd = hci_open_dev(id);
-	if (dd < 0) {
-		error("HCI device open failed: hci%d", id);
-		memset(&rp, 0, sizeof(rp));
-	} else {
-		memset(&rq, 0, sizeof(rq));
-		rq.ogf    = OGF_HOST_CTL;
-		rq.ocf    = OCF_READ_LOCAL_NAME;
-		rq.rparam = &rp;
-		rq.rlen   = READ_LOCAL_NAME_RP_SIZE;
-		rq.event  = EVT_CMD_COMPLETE;
-
-		if (hci_send_req(dd, &rq, HCI_REQ_TIMEOUT) < 0) {
-			error("Sending getting name command failed: %s (%d)",
-						strerror(errno), errno);
-			rp.name[0] = '\0';
-		} else if (rp.status) {
-			error("Getting name failed with status 0x%02x",
-					rp.status);
-			rp.name[0] = '\0';
-		}
-		hci_close_dev(dd);
-	}
-
-	strncpy(name, pname, sizeof(name) - 1);
-	name[248] = '\0';
-	pname = name;
-
-	adapter_name_changed(adapter, pname);
-}
-
 void hcid_dbus_setscan_enable_complete(bdaddr_t *local)
 {
 	struct btd_adapter *adapter;
@@ -1112,9 +842,9 @@ void hcid_dbus_write_simple_pairing_mode_complete(bdaddr_t *local)
 		return;
 	}
 
-	adapter_update_ssp_mode(adapter, dd, mode);
-
 	hci_close_dev(dd);
+
+	adapter_update_ssp_mode(adapter, mode);
 }
 
 int hcid_dbus_get_io_cap(bdaddr_t *local, bdaddr_t *remote,
@@ -1216,159 +946,6 @@ int hcid_dbus_set_io_cap(bdaddr_t *local, bdaddr_t *remote,
 	return 0;
 }
 
-int inquiry_cancel(int dd, int to)
-{
-	struct hci_request rq;
-	uint8_t status;
-
-	memset(&rq, 0, sizeof(rq));
-	rq.ogf    = OGF_LINK_CTL;
-	rq.ocf    = OCF_INQUIRY_CANCEL;
-	rq.rparam = &status;
-	rq.rlen   = sizeof(status);
-	rq.event = EVT_CMD_COMPLETE;
-
-	if (hci_send_req(dd, &rq, to) < 0)
-		return -1;
-
-	if (status) {
-		errno = bt_error(status);
-		return -1;
-	}
-
-	return 0;
-}
-
-static int remote_name_cancel(int dd, bdaddr_t *dba, int to)
-{
-	remote_name_req_cancel_cp cp;
-	struct hci_request rq;
-	uint8_t status;
-
-	memset(&rq, 0, sizeof(rq));
-	memset(&cp, 0, sizeof(cp));
-
-	bacpy(&cp.bdaddr, dba);
-
-	rq.ogf    = OGF_LINK_CTL;
-	rq.ocf    = OCF_REMOTE_NAME_REQ_CANCEL;
-	rq.cparam = &cp;
-	rq.clen   = REMOTE_NAME_REQ_CANCEL_CP_SIZE;
-	rq.rparam = &status;
-	rq.rlen = sizeof(status);
-	rq.event = EVT_CMD_COMPLETE;
-
-	if (hci_send_req(dd, &rq, to) < 0)
-		return -1;
-
-	if (status) {
-		errno = bt_error(status);
-		return -1;
-	}
-
-	return 0;
-}
-
-int cancel_discovery(struct btd_adapter *adapter)
-{
-	struct remote_dev_info *dev, match;
-	int dd, err = 0;
-	uint16_t dev_id = adapter_get_dev_id(adapter);
-
-	dd = hci_open_dev(dev_id);
-	if (dd < 0)
-		return -ENODEV;
-
-	/*
-	 * If there is a pending read remote name request means
-	 * that the inquiry complete event was already received
-	 */
-	memset(&match, 0, sizeof(struct remote_dev_info));
-	bacpy(&match.bdaddr, BDADDR_ANY);
-	match.name_status = NAME_REQUESTED;
-
-	dev = adapter_search_found_devices(adapter, &match);
-	if (dev) {
-		if (remote_name_cancel(dd, &dev->bdaddr,
-							HCI_REQ_TIMEOUT) < 0) {
-			err = -errno;
-			error("Read remote name cancel failed: %s, (%d)",
-						strerror(errno), errno);
-		}
-	} else {
-		if (inquiry_cancel(dd, HCI_REQ_TIMEOUT) < 0) {
-			err = -errno;
-			error("Inquiry cancel failed:%s (%d)",
-						strerror(errno), errno);
-		}
-	}
-
-	hci_close_dev(dd);
-
-	return err;
-}
-
-int periodic_inquiry_exit(int dd, int to)
-{
-	struct hci_request rq;
-	uint8_t status;
-
-	memset(&rq, 0, sizeof(rq));
-	rq.ogf    = OGF_LINK_CTL;
-	rq.ocf    = OCF_EXIT_PERIODIC_INQUIRY;
-	rq.rparam = &status;
-	rq.rlen   = sizeof(status);
-	rq.event = EVT_CMD_COMPLETE;
-
-	if (hci_send_req(dd, &rq, to) < 0)
-		return -1;
-
-	if (status) {
-		errno = status;
-		return -1;
-	}
-
-	return 0;
-}
-
-int cancel_periodic_discovery(struct btd_adapter *adapter)
-{
-	struct remote_dev_info *dev, match;
-	int dd, err = 0;
-	uint16_t dev_id = adapter_get_dev_id(adapter);
-
-	dd = hci_open_dev(dev_id);
-	if (dd < 0)
-		return -ENODEV;
-
-	/* find the pending remote name request */
-	memset(&match, 0, sizeof(struct remote_dev_info));
-	bacpy(&match.bdaddr, BDADDR_ANY);
-	match.name_status = NAME_REQUESTED;
-
-	dev = adapter_search_found_devices(adapter, &match);
-	if (dev) {
-		if (remote_name_cancel(dd, &dev->bdaddr,
-						HCI_REQ_TIMEOUT) < 0) {
-			err = -errno;
-			error("Read remote name cancel failed: %s, (%d)",
-						strerror(errno), errno);
-		}
-	}
-
-	/* ovewrite err if necessary: stop periodic inquiry has higher
-	 * priority */
-	if (periodic_inquiry_exit(dd, HCI_REQ_TIMEOUT) < 0) {
-		err = -errno;
-		error("Periodic Inquiry exit failed:%s (%d)",
-						strerror(errno), errno);
-	}
-
-	hci_close_dev(dd);
-
-	return err;
-}
-
 /* Most of the functions in this module require easy access to a connection so
  * we keep it global here and provide these access functions the other (few)
  * modules that require access to it */
